==> FK-2_8_6.tar.bz2: FK-2_8_6/FK/GenMatrix.h <==
/****************************************************************************
 *
 *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
 *	Tokyo University of Technology, All rights reserved.
 *
 *	Redistribution and use in source and binary forms,
 *	with or without modification, are permitted provided that the
 *	following conditions are met:
 *
 *		- Redistributions of source code must retain the above
 *			copyright notice, this list of conditions and the
 *			following disclaimer.
 *
 *		- Redistributions in binary form must reproduce the above
 *			copyright notice, this list of conditions and the
 *			following disclaimer in the documentation and/or
 *			other materials provided with the distribution.
 *
 *		- Neither the name of the copyright holders nor the names
 *			of its contributors may be used to endorse or promote
 *			products derived from this software without specific
 *			prior written permission.
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *	"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *	LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *	FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *	COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 *	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *	SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *	HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 *	STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 *	IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *	POSSIBILITY OF SUCH DAMAGE. 
 *
 ****************************************************************************/
/****************************************************************************
 *
 *	Copyright (c) 1999-2008, Watanabe Lab, School of Media Science,
 *	Tokyo University of Technology, All rights reserved.
 *
 *	本ソフトウェアおよびソースコードのライセンスは、基本的に
 *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
 *
 *	ソースコード形式かバイナリ形式か、変更するかしないかを問わず、
 *	以下の条件を満たす場合に限り、再頒布および使用が許可されます。
 *
 *	- ソースコードを再頒布する場合、上記の著作権表示、本条件一覧、
 *		および下記免責条項を含めること。
 *
 *	- バイナリ形式で再頒布する場合、頒布物に付属のドキュメント等の
 *		資料に、上記の著作権表示、本条件一覧、および下記免責条項を
 *		含めること。
 *
 *	- 書面による特別の許可なしに、本ソフトウェアから派生した製品の
 *		宣伝または販売促進に、本ソフトウェアの著作権者の名前または
 *		コントリビューターの名前を使用してはならない。
 *
 *	本ソフトウェアは、著作権者およびコントリビューターによって「現
 *	状のまま」提供されており、明示黙示を問わず、商業的な使用可能性、
 *	および特定の目的に対する適合性に関す暗黙の保証も含め、またそれ
 *	に限定されない、いかなる保証もないものとします。著作権者もコン
 *	トリビューターも、事由のいかんを問わず、損害発生の原因いかんを
 *	問わず、かつ責任の根拠が契約であるか厳格責任であるか(過失その
 *	他の)不法行為であるかを問わず、仮にそのような損害が発生する可
 *	能性を知らされていたとしても、本ソフトウェアの使用によって発生
 *	した(代替品または代用サービスの調達、使用の喪失、データの喪失、
 *	利益の喪失、業務の中断も含め、またそれに限定されない)直接損害、
 *	間接損害、偶発的な損害、特別損害、懲罰的損害、または結果損害に
 *	ついて、一切責任を負わないものとします。
 *
 ****************************************************************************/
#ifndef __FK_GEN_MATRIX_HEADER__
#define __FK_GEN_MATRIX_HEADER__

#include <FK/GenVector.h>
#include <FK/Matrix.h>

class fk_GenMatrix {

	friend class		fk_GenVector;
	
  private:
	vector<double>		m;
	int					deg;

	void				MultVec(fk_GenVector &, const fk_GenVector &) const;
	void				MakeIdentMatrix(void);
	void				MakeZeroMatrix(void);
	bool				MatrixInverse(void);

 public:
	
	// コンストラクタ (引数は次数)
	fk_GenMatrix(int = 0);
	// コピーコンストラクタ
	fk_GenMatrix(const fk_GenMatrix &);

	//////// 演算子群
	// 単項演算子
	fk_GenMatrix	operator !(void) const;		// 逆行列を返す(自身は不変)

	// 比較演算子 
	bool	operator ==(const fk_GenMatrix &) const; // 同値演算子
	bool	operator !=(const fk_GenMatrix &) const; // 否定同値演算子

	// 代入演算子 
	fk_GenMatrix &		operator =(const fk_GenMatrix &);		// 代入 
	fk_GenMatrix &		operator +=(const fk_GenMatrix &);		// 和 
	fk_GenMatrix &		operator -=(const fk_GenMatrix &);		// 差 
	fk_GenMatrix &		operator *=(const fk_GenMatrix &);		// 積 	


	//////// メンバ関数群
	// 初期化 (true で単位行列、false で零行列)
	void			init(bool = true);

	// 次数設定 (直前の値は保持)
	void			setDeg(int);

	// 次数取得
	int				getDeg(void) const;

	// 成分設定 (行番号, 列番号, 値)
	void			set(int, int, double);

	// 成分取得 (行番号, 列番号)
	double			get(int, int) const;

	// 自身逆行列化し、結果を返す
	bool			inverse(void);

	// 自身転置
	void			negate(void);

	// 特異行列判定
	bool			isSingular(void) const;

	// 正則行列判定
	bool			isRegular(void) const;

	// 行列要素の標準出力
	void			Print(string = "") const;


	//////// friend 演算子群
	friend fk_GenVector & fk_GenVector::operator *=(const fk_GenMatrix &);
	// 二項演算子 
	// 行列変換 
	friend fk_GenVector	operator *(const fk_GenMatrix &, const fk_GenVector &);
	// 行列和 
	friend fk_GenMatrix	operator +(const fk_GenMatrix &, const fk_GenMatrix &);
	// 行列差 
	friend fk_GenMatrix	operator -(const fk_GenMatrix &, const fk_GenMatrix &);
	// 行列積 
	friend fk_GenMatrix	operator *(const fk_GenMatrix &, const fk_GenMatrix &);
};	

//////// 二項演算子の外部関数宣言

// fk_GenVector との積演算
fk_GenVector	operator *(const fk_GenMatrix &, const fk_GenVector &);

// 和演算子
fk_GenMatrix	operator +(const fk_GenMatrix &, const fk_GenMatrix &);

// 差演算子
fk_GenMatrix	operator -(const fk_GenMatrix &, const fk_GenMatrix &);

// 積演算子
fk_GenMatrix	operator *(const fk_GenMatrix &, const fk_GenMatrix &);


#endif // !__FK_GEN_MATRIX_HEADER__

==> FK-2_8_7.tar.bz2: FK-2_8_7/FK/GenMatrix.h <==
/****************************************************************************
 *
 *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
 *	Tokyo University of Technology, All rights reserved.
 *
 *	Redistribution and use in source and binary forms,
 *	with or without modification, are permitted provided that the
 *	following conditions are met:
 *
 *		- Redistributions of source code must retain the above
 *			copyright notice, this list of conditions and the
 *			following disclaimer.
 *
 *		- Redistributions in binary form must reproduce the above
 *			copyright notice, this list of conditions and the
 *			following disclaimer in the documentation and/or
 *			other materials provided with the distribution.
 *
 *		- Neither the name of the copyright holders nor the names
 *			of its contributors may be used to endorse or promote
 *			products derived from this software without specific
 *			prior written permission.
 *
 *	THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *	"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *	LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 *	FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 *	COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 *	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 *	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 *	SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *	HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 *	STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 *	IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 *	POSSIBILITY OF SUCH DAMAGE. 
 *
 ****************************************************************************/
/****************************************************************************
 *
 *	Copyright (c) 1999-2009, Watanabe Lab, School of Media Science,
 *	Tokyo University of Technology, All rights reserved.
 *
 *	本ソフトウェアおよびソースコードのライセンスは、基本的に
 *	「修正 BSD ライセンス」に従います。以下にその詳細を記します。
 *
 *	ソースコード形式かバイナリ形式か、変更するかしないかを問わず、
 *	以下の条件を満たす場合に限り、再頒布および使用が許可されます。
 *
 *	- ソースコードを再頒布する場合、上記の著作権表示、本条件一覧、
 *		および下記免責条項を含めること。
 *
 *	- バイナリ形式で再頒布する場合、頒布物に付属のドキュメント等の
 *		資料に、上記の著作権表示、本条件一覧、および下記免責条項を
 *		含めること。
 *
 *	- 書面による特別の許可なしに、本ソフトウェアから派生した製品の
 *		宣伝または販売促進に、本ソフトウェアの著作権者の名前または
 *		コントリビューターの名前を使用してはならない。
 *
 *	本ソフトウェアは、著作権者およびコントリビューターによって「現
 *	状のまま」提供されており、明示黙示を問わず、商業的な使用可能性、
 *	および特定の目的に対する適合性に関す暗黙の保証も含め、またそれ
 *	に限定されない、いかなる保証もないものとします。著作権者もコン
 *	トリビューターも、事由のいかんを問わず、損害発生の原因いかんを
 *	問わず、かつ責任の根拠が契約であるか厳格責任であるか(過失その
 *	他の)不法行為であるかを問わず、仮にそのような損害が発生する可
 *	能性を知らされていたとしても、本ソフトウェアの使用によって発生
 *	した(代替品または代用サービスの調達、使用の喪失、データの喪失、
 *	利益の喪失、業務の中断も含め、またそれに限定されない)直接損害、
 *	間接損害、偶発的な損害、特別損害、懲罰的損害、または結果損害に
 *	ついて、一切責任を負わないものとします。
 *
 ****************************************************************************/
#ifndef __FK_GEN_MATRIX_HEADER__
#define __FK_GEN_MATRIX_HEADER__

#include <FK/GenVector.h>
#include <FK/Matrix.h>

class fk_GenMatrix {

	friend class		fk_GenVector;
	
  private:
	std::vector<double>	m;
	int					deg;

	void				MultVec(fk_GenVector &, const fk_GenVector &) const;
	void				MakeIdentMatrix(void);
	void				MakeZeroMatrix(void);
	bool				MatrixInverse(void);

 public:
	
	// コンストラクタ (引数は次数)
	fk_GenMatrix(int = 0);
	// コピーコンストラクタ
	fk_GenMatrix(const fk_GenMatrix &);

	//////// 演算子群
	// 単項演算子
	fk_GenMatrix	operator !(void) const;		// 逆行列を返す(自身は不変)

	// 比較演算子 
	bool	operator ==(const fk_GenMatrix &) const; // 同値演算子
	bool	operator !=(const fk_GenMatrix &) const; // 否定同値演算子

	// 代入演算子 
	fk_GenMatrix &		operator =(const fk_GenMatrix &);		// 代入 
	fk_GenMatrix &		operator +=(const fk_GenMatrix &);		// 和 
	fk_GenMatrix &		operator -=(const fk_GenMatrix &);		// 差 
	fk_GenMatrix &		operator *=(const fk_GenMatrix &);		// 積 	


	//////// メンバ関数群
	// 初期化 (true で単位行列、false で零行列)
	void			init(bool = true);

	// 次数設定 (直前の値は保持)
	void			setDeg(int);

	// 次数取得
	int				getDeg(void) const;

	// 成分設定 (行番号, 列番号, 値)
	void			set(int, int, double);

	// 成分取得 (行番号, 列番号)
	double			get(int, int) const;

	// 自身逆行列化し、結果を返す
	bool			inverse(void);

	// 自身転置
	void			negate(void);

	// 特異行列判定
	bool			isSingular(void) const;

	// 正則行列判定
	bool			isRegular(void) const;

	// 行列要素の標準出力
	void			Print(std::string = "") const;


	//////// friend 演算子群
	friend fk_GenVector & fk_GenVector::operator *=(const fk_GenMatrix &);
	// 二項演算子 
	// 行列変換 
	friend fk_GenVector	operator *(const fk_GenMatrix &, const fk_GenVector &);
	// 行列和 
	friend fk_GenMatrix	operator +(const fk_GenMatrix &, const fk_GenMatrix &);
	// 行列差 
	friend fk_GenMatrix	operator -(const fk_GenMatrix &, const fk_GenMatrix &);
	// 行列積 
	friend fk_GenMatrix	operator *(const fk_GenMatrix &, const fk_GenMatrix &);
};	

//////// 二項演算子の外部関数宣言

// fk_GenVector との積演算
fk_GenVector	operator *(const fk_GenMatrix &, const fk_GenVector &);

// 和演算子
fk_GenMatrix	operator +(const fk_GenMatrix &, const fk_GenMatrix &);

// 差演算子
fk_GenMatrix	operator -(const fk_GenMatrix &, const fk_GenMatrix &);

// 積演算子
fk_GenMatrix	operator *(const fk_GenMatrix &, const fk_GenMatrix &);


#endif // !__FK_GEN_MATRIX_HEADER__
